@@ -6,5 +6,5 @@ from ._version import get_versions  # isort:skip
 __version__ = get_versions()["version"]
 del get_versions
 
-from scmdata.dataframe import ScmDataFrame, df_append  # noqa: F401
-from scmdata.run import ScmRun  # noqa: F401
+from scmdata.dataframe import ScmDataFrame, df_append  # noqa: F401, E402
+from scmdata.run import ScmRun  # noqa: F401, E402
