@@ -34,7 +34,7 @@ from .netcdf import inject_nc_methods
 from .offsets import generate_range, to_offset
 from .plotting import inject_plotting_methods
 from .pyam_compat import IamDataFrame, LongDatetimeIamDataFrame
-from .time import TimePoints
+from .time import _TARGET_DTYPE, TimePoints
 from .timeseries import TimeSeries
 from .units import UnitConverter
 
@@ -134,11 +134,6 @@ def _format_data(  # pylint: disable=missing-return-doc
     if isinstance(df, pd.Series):
         df = df.to_frame()
 
-    # all lower case
-    str_cols = [c for c in df.columns if isinstance(c, str)]
-    if str_cols:
-        df.rename(columns={c: str(c).lower() for c in str_cols}, inplace=True)
-
     # reset the index if meaningful entries are included there
     if list(df.index.names) != [None]:
         df.reset_index(inplace=True)
@@ -287,7 +282,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         self,
         data,
         index: Any = None,
-        columns: Optional[Dict[str, list]] = None,
+        columns: Optional[Union[Dict[str, list], Dict[str, str]]] = None,
         **kwargs: Any,
     ):
         """
@@ -454,30 +449,105 @@ class ScmRun:  # pylint: disable=too-many-public-methods
 
         raise KeyError("[{}] is not in metadata".format(key))
 
-    def __setitem__(  # pylint: disable=inconsistent-return-statements
-        self, key: Any, value: Any
+    def __setitem__(
+        self, key: str, value: Union[np.ndarray, list, int, float, str]
     ) -> Any:
         """
-        Set item of self with helpful direct access.
+        Update metadata
 
-        Provides direct access to set "time" as well as the columns in :attr:`meta`.
+        Notes
+        -----
+        If the meta values changes are applied to a filtered subset, the change will be reflected
+        in the original :obj:`ScmRun` object.
+
+        .. code:: python
+
+            >>> df
+            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
+            Time:
+                Start: 2005-01-01T00:00:00
+                End: 2015-01-01T00:00:00
+            Meta:
+                   model     scenario region             variable   unit climate_model
+                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model
+                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model
+                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       a_model
+            >>> df["climate_model"] = ["a_model", "a_model", "b_model"]
+            >>> df
+            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
+            Time:
+                Start: 2005-01-01T00:00:00
+                End: 2015-01-01T00:00:00
+            Meta:
+                   model     scenario region             variable   unit climate_model
+                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model
+                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model
+                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       b_model
+            >>> df2 = df.filter(variable="Primary Energy")
+            >>> df2["pe_only"] = True
+            >>> df2
+            <scmdata.ScmRun (timeseries: 2, timepoints: 3)>
+            Time:
+                Start: 2005-01-01T00:00:00
+                End: 2015-01-01T00:00:00
+            Meta:
+                   model     scenario region             variable   unit climate_model pe_only
+                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model    True
+                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       b_model    True
+            >>> df
+            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
+            Time:
+                Start: 2005-01-01T00:00:00
+                End: 2015-01-01T00:00:00
+            Meta:
+                   model     scenario region             variable   unit climate_model pe_only
+                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model    True
+                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model     NaN
+                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       b_model    True
+
+        Parameters
+        ----------
+        key
+            Column name
+
+        value
+            Values to write
+
+            If a list of values is provided, then the length of that :obj:`value` must be the same as the number of timeseries
+
+        Raises
+        ------
+        ValueError
+            If the length of :obj:`meta` is inconsistent with the number of timeseries
         """
+        meta = np.atleast_1d(value)
         if key == "time":
-            self._time_points = TimePoints(value)
+            self._time_points = TimePoints(meta)
             for ts in self._ts:
-                if len(value) != len(ts):
+                if len(meta) != len(ts):
                     raise ValueError(
                         "New time series is the incorrect length (expected: {}, got: {})".format(
-                            len(value), len(ts)
+                            len(meta), len(ts)
                         )
                     )
                 ts["time"] = self._time_points.values
-            return self._time_points.values
-        return self.set_meta(value, name=key)
+        else:
+            if len(meta) == 1:
+                for ts in self._ts:
+                    ts.meta[key] = meta[0]
+            elif len(meta) == len(self):
+                for i, ts in enumerate(self._ts):
+                    ts.meta[key] = meta[i]
+            else:
+                raise ValueError(
+                    "Invalid length for metadata, `{}`, must be 1 or equal to the number of timeseries, `{}`".format(
+                        len(meta), len(self)
+                    )
+                )
 
     def __repr__(self):
         def _indent(s):
-            lines = ["\t" + l for l in s.split("\n")]
+            lines = ["\t" + line for line in s.split("\n")]
             return "\n".join(lines)
 
         meta_str = _indent(self.meta.__repr__())
@@ -509,6 +579,48 @@ class ScmRun:  # pylint: disable=too-many-public-methods
 
         return func
 
+    def drop_meta(self, columns: Union[list, str], inplace: bool = True):
+        """
+        Drop metadata columns out of the Run
+
+        Notes
+        -----
+        If this operation is not performed inplace, the current object is deep copied. Any changes to the :obj:`Timeseries` of
+        the returned object will not be reflected in the original object
+
+        Parameters
+        ----------
+        columns
+            The column or columns to drop
+        inplace
+            If True, do operation inplace and return None
+
+        Raises
+        ------
+        KeyError
+            If any of the columns do not exist in the meta :class:`DataFrame`
+        """
+        if inplace:
+            df = self
+        else:
+            df = self.copy(copy_ts=True)
+
+        if isinstance(columns, str):
+            columns = [columns]
+
+        existing_cols = df.meta_attributes
+        for c in columns:
+            if c not in existing_cols:
+                raise KeyError(c)
+
+        # pylint: disable=protected-access
+        for ts in df._ts:
+            for c in columns:
+                del ts._data.attrs[c]
+
+        if not inplace:
+            return df
+
     @property
     def meta_attributes(self):
         """
@@ -535,42 +647,120 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         """
         return self._time_points
 
-    def timeseries(
-        self, meta: Optional[List[str]] = None, check_duplicated: bool = True
-    ) -> pd.DataFrame:
+    def timeseries(self, meta=None, check_duplicated=True, time_axis=None):
         """
         Return the data with metadata as a :obj:`pd.DataFrame`.
 
         Parameters
         ----------
-        meta
-            The list of meta columns that will be included in the output's MultiIndex.
-            If None (default), then all metadata will be used.
+        meta : list[str]
+            The list of meta columns that will be included in the output's
+            MultiIndex. If None (default), then all metadata will be used.
 
-        check_duplicated
-            If True, an exception is raised if any of the timeseries have duplicated metadata
+        check_duplicated : bool
+            If True, an exception is raised if any of the timeseries have
+            duplicated metadata
+
+        time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
+            Time axis to use for the output's columns. If `None`,
+            :class:`datetime.datetime` objects will be used. If `"year"`, the
+            year of each time point  will be used. If `"year-month", the year
+            plus (month - 0.5) / 12  will be used. If
+            `"days since 1970-01-01"`, the number of days  since 1st Jan 1970
+            will be used (calculated using the ``datetime``  module). If
+            `"seconds since 1970-01-01"`, the number of seconds  since 1st Jan
+            1970 will be used (calculated using the ``datetime`` module).
 
         Returns
         -------
         :obj:`pd.DataFrame`
-            DataFrame with datetimes as columns and timeseries as rows. Metadata is in
-            the index.
+            DataFrame with datetimes as columns and timeseries as rows.
+            Metadata is in the index.
 
         Raises
         ------
         ValueError
-            If the metadata are not unique between timeseries
+            If the metadata are not unique between timeseries and
+            ``check_duplicated`` is ``True``
+
+        NotImplementedError
+            The value of `time_axis` is not recognised
+
+        ValueError
+            The value of `time_axis` would result in columns which aren't unique
         """
         df = pd.DataFrame(self.values)
         _meta = self.meta if meta is None else self.meta[meta]
         if check_duplicated and _meta.duplicated().any():
             raise ValueError("Duplicated meta values")
 
-        df.columns = self._time_points.to_index()
+        if time_axis is None:
+            columns = self._time_points.to_index()
+        elif time_axis == "year":
+            columns = self._time_points.years()
+        elif time_axis == "year-month":
+            columns = (
+                self._time_points.years() + (self._time_points.months() - 0.5) / 12
+            )
+        elif time_axis == "days since 1970-01-01":
+
+            def calc_days(x):
+                ref = np.array(["1970-01-01"], dtype=_TARGET_DTYPE)[0]
+
+                return (x - ref).astype("timedelta64[D]")
+
+            columns = calc_days(self._time_points.values).astype(int)
+
+        elif time_axis == "seconds since 1970-01-01":
+
+            def calc_seconds(x):
+                ref = np.array(["1970-01-01"], dtype=_TARGET_DTYPE)[0]
+
+                return x - ref
+
+            columns = calc_seconds(self._time_points.values).astype(int)
+
+        else:
+            raise NotImplementedError("time_axis = '{}'".format(time_axis))
+
+        if len(np.unique(columns)) != len(columns):
+            raise ValueError(
+                "Ambiguous time values with time_axis = '{}'".format(time_axis)
+            )
+
+        df.columns = columns
+        df.columns.name = "time"
         df.index = pd.MultiIndex.from_arrays(_meta.values.T, names=_meta.columns)
 
         return df
 
+    def long_data(self, time_axis=None):
+        """
+        Return data in long form, particularly useful for plotting with seaborn
+
+        Parameters
+        ----------
+        time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
+            Time axis to use for the output's columns. If `None`,
+            :class:`datetime.datetime` objects will be used. If `"year"`, the
+            year of each time point  will be used. If `"year-month", the year
+            plus (month - 0.5) / 12  will be used. If
+            `"days since 1970-01-01"`, the number of days  since 1st Jan 1970
+            will be used (calculated using the ``datetime``  module). If
+            `"seconds since 1970-01-01"`, the number of seconds  since 1st Jan
+            1970 will be used (calculated using the ``datetime`` module).
+
+        Returns
+        -------
+        :obj:`pd.DataFrame`
+            :obj:`pd.DataFrame` containing the data in 'long form' (i.e. one observation per row).
+        """
+        out = self.timeseries(time_axis=time_axis).stack()
+        out.name = "value"
+        out = out.to_frame().reset_index()
+
+        return out
+
     @property
     def shape(self) -> tuple:
         """
@@ -600,6 +790,18 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         """
         return np.asarray([ts._data.values for ts in self._ts])
 
+    @property
+    def empty(self) -> bool:
+        """
+        Indicate whether :obj:`ScmRun` is empty i.e. contains no data
+
+        Returns
+        -------
+        bool
+            If :obj:`ScmRun` is empty, return ``True``, if not return ``False``
+        """
+        return np.equal(len(self._ts), 0)
+
     @property
     def meta(self) -> pd.DataFrame:
         """
@@ -630,7 +832,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         Return a filtered ScmRun (i.e., a subset of the data).
 
         Note that this this does not copy the underlying time-series data so any modifications will be reflected in the caller
-        ``ScmRun``. This allows for the updating a subset of the timeseries directly.
+        :obj`ScmRun`. This allows for the updating a subset of the timeseries directly.
 
         .. code:: python
 
@@ -697,44 +899,44 @@ class ScmRun:  # pylint: disable=too-many-public-methods
               :class:`str`)
 
             If ``regexp=True`` is included in :obj:`kwargs` then the pseudo-regexp
-            syntax in :obj:`pattern_match` is disabled.
+            syntax in :func:`pattern_match` is disabled.
 
         Returns
         -------
         :obj:`ScmRun`
-            If not :obj:`inplace`, return a new instance with the filtered data.
+            If not ``inplace``, return a new instance with the filtered data.
 
         Raises
         ------
         AssertionError
             Data and meta become unaligned
         """
-        _keep_times, _keep_cols = self._apply_filters(kwargs, has_nan)
+        _keep_times, _keep_rows = self._apply_filters(kwargs, has_nan)
         ret = copy.copy(self) if not inplace else self
 
-        if not keep and sum(~_keep_cols) and sum(~_keep_times):
+        if not keep and sum(~_keep_rows) and sum(~_keep_times):
             raise ValueError(
                 "If keep==False, filtering cannot be performed on the temporal axis "
                 "and with metadata at the same time"
             )
 
         reduce_times = (~_keep_times).sum() > 0
-        reduce_cols = (~_keep_cols).sum() > 0
+        reduce_rows = (~_keep_rows).sum() > 0
 
         if not keep:
             _keep_times = ~_keep_times
-            _keep_cols = ~_keep_cols
+            _keep_rows = ~_keep_rows
 
-            if not reduce_cols and not reduce_times:
+            if not reduce_rows and not reduce_times:
                 # When nothing is filtered, drop everything
-                reduce_cols = True
+                reduce_rows = True
 
         # Filter the timeseries first
         # I wish lists had the same indexing interface as ndarrays
-        if reduce_cols:
-            ret._ts = [ret._ts[i] for i, v in enumerate(_keep_cols) if v]
+        if reduce_rows:
+            ret._ts = [ret._ts[i] for i, v in enumerate(_keep_rows) if v]
 
-        # Then filter the timeseries if needed
+        # Then filter the times if needed
         if reduce_times:
             ret._ts = [ts[_keep_times] for ts in ret._ts]
             ret["time"] = self.time_points.values[_keep_times]
@@ -888,101 +1090,6 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         """
         return self.timeseries().tail(*args, **kwargs)
 
-    def set_meta(
-        self,
-        meta: Union[pd.Series, list, int, float, str],
-        name: Optional[str] = None,
-        index: Optional[Union[pd.DataFrame, pd.Series, pd.Index, pd.MultiIndex]] = None,
-    ) -> None:
-        """
-        Set metadata information.
-
-        This function has been deprecated and may be removed in future. Use the `[]` accessor
-        to update metadata instead.
-
-        .. code:: python
-
-            >>> df
-            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
-            Time:
-                Start: 2005-01-01T00:00:00
-                End: 2015-01-01T00:00:00
-            Meta:
-                   model     scenario region             variable   unit climate_model
-                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model
-                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model
-                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       a_model
-            >>> df["climate_model"] = ["a_model", "a_model", "b_model"]
-            >>> df
-            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
-            Time:
-                Start: 2005-01-01T00:00:00
-                End: 2015-01-01T00:00:00
-            Meta:
-                   model     scenario region             variable   unit climate_model
-                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model
-                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model
-                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       b_model
-            >>> df.filter(variable="Primary Energy")["pe_only"] = True
-            >>> df
-            <scmdata.ScmRun (timeseries: 3, timepoints: 3)>
-            Time:
-                Start: 2005-01-01T00:00:00
-                End: 2015-01-01T00:00:00
-            Meta:
-                   model     scenario region             variable   unit climate_model pe_only
-                0  a_iam   a_scenario  World       Primary Energy  EJ/yr       a_model    True
-                1  a_iam   a_scenario  World  Primary Energy|Coal  EJ/yr       a_model     NaN
-                2  a_iam  a_scenario2  World       Primary Energy  EJ/yr       b_model    True
-
-        Parameters
-        ----------
-        meta
-            Column to be added to metadata
-
-        name
-            Meta column name (defaults to :obj:`meta.name`)
-
-        index
-            *DEPRECATED* The index to which the metadata is to be applied.
-
-            This argument has been deprecated, but kept for compatibility with :class:`ScmDataFrame`
-
-
-        Raises
-        ------
-        ValueError
-            No name can be determined from inputs or index cannot be coerced to
-            :class:`pd.MultiIndex`
-
-        NotImplementedError
-            Any non-None value for `index` is provided
-        """
-        # check that name is valid and doesn't conflict with data columns
-        # mypy doesn't recognise if
-        if (name or (hasattr(meta, "name") and meta.name)) in [  # type: ignore
-            None,
-            False,
-        ]:
-            raise ValueError("Must pass a name or use a named pd.Series")
-        # mpy doesn't recognise if checks
-        name = name or meta.name  # type: ignore
-
-        if index is not None:
-            raise NotImplementedError(
-                "Removed `index` functionality. Filter and then set meta instead"
-            )
-
-        meta = np.atleast_1d(meta)
-        if len(meta) == 1:
-            for ts in self._ts:
-                ts.meta[name] = meta[0]
-        elif len(meta) == len(self):
-            for i, ts in enumerate(self._ts):
-                ts.meta[name] = meta[i]
-        else:
-            raise ValueError("Invalid shape for metadata")
-
     def get_unique_meta(
         self, meta: str, no_duplicates: Optional[bool] = False,
     ) -> Union[List[Any], Any]:
@@ -1392,8 +1499,10 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         def apply_units(group):
             orig_unit = group.get_unique_meta("unit", no_duplicates=True)
             uc = UnitConverter(orig_unit, unit, context=context)
+
             for ts in group._ts:  # todo: fix when we have an apply function
                 ts._data[:] = uc.convert_from(ts._data.values)
+
             group["unit"] = unit
             group["unit_context"] = context
             return group
@@ -1404,9 +1513,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         if not inplace:
             return ret
 
-    def relative_to_ref_period_mean(
-        self, append_str: Optional[str] = None, **kwargs: Any
-    ) -> pd.DataFrame:
+    def relative_to_ref_period_mean(self, append_str=None, **kwargs):
         """
         Return the timeseries relative to a given reference period mean.
 
@@ -1415,10 +1522,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         Parameters
         ----------
         append_str
-            String to append to the name of all the variables in the resulting DataFrame
-            to indicate that they are relevant to a given reference period. E.g. `'rel.
-            to 1961-1990'`. If None, this will be autofilled with the keys and ranges of
-            :obj:`kwargs`.
+            Deprecated
 
         **kwargs
             Arguments to pass to :func:`filter` to determine the data to be included in
@@ -1426,27 +1530,31 @@ class ScmRun:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        :obj:`pd.DataFrame`
-            DataFrame containing the timeseries, adjusted to the reference period mean
+        :obj:`ScmDataFrame`
+            New object containing the timeseries, adjusted to the reference period mean.
+            The reference period year bounds are stored in the meta columns
+            ``"reference_period_start_year"`` and ``"reference_period_end_year"``.
+
+        Raises
+        ------
+        NotImplementedError
+            ``append_str`` is not ``None``
         """
+        if append_str is not None:
+            raise NotImplementedError("`append_str` is deprecated")
+
         ts = self.timeseries()
         # mypy confused by `inplace` default
-        ref_period_mean = (
-            self.filter(**kwargs).timeseries().mean(axis="columns")  # type: ignore
-        )
+        ref_data = self.filter(**kwargs)
+        ref_period_mean = ref_data.timeseries().mean(axis="columns")  # type: ignore
 
         res = ts.sub(ref_period_mean, axis="rows")
         res.reset_index(inplace=True)
 
-        if append_str is None:
-            append_str = ";".join(
-                ["{}: {} - {}".format(k, v[0], v[-1]) for k, v in kwargs.items()]
-            )
-            append_str = "(ref. period {})".format(append_str)
+        res["reference_period_start_year"] = ref_data["year"].min()
+        res["reference_period_end_year"] = ref_data["year"].max()
 
-        res["variable"] = res["variable"].apply(lambda x: "{} {}".format(x, append_str))
-
-        return res.set_index(ts.index.names)
+        return type(self)(res)
 
     def append(
         self,
@@ -1662,8 +1770,10 @@ def df_append(
         if not np.array_equal(new_t, r.time_points):
             all_valid_times = False
     if not all_valid_times:
-        ret._ts = [ts.reindex(new_t) for ts in ret._ts]
+        # Time values are converted to cftime to avoid OutOfBoundsDatetime errors
         ret._time_points = TimePoints(new_t)
+        new_t_cftime = ret._time_points.as_cftime()
+        ret._ts = [ts.reindex(new_t_cftime) for ts in ret._ts]
 
     if ret.meta.duplicated().any():
         if duplicate_msg:
